# llamaindex-openai_query-agent
A simple demonstration of LLama index AI Agent framework to perform vector search

> [!IMPORTANT]  
> You will need to create a .env file and populate it with the following environment variables:
- PINECONE_API_KEY
- OPENAI_API_KEY